//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

#ifndef BACKEND_ALBUM_H
#define BACKEND_ALBUM_H

//representative image sizes
#define SMALL 1
#define MEDIUM 2
#define LARGE 3

//--------------------
//forward declarations
class QString;
class QPixmap;
class Subalbum;
class LoadDialog;
class SaveDialog;
class SubalbumPreviewWidget;
//--------------------

//=====================================
/*! \brief An album contains Subalbums.
 *
 *  Specific contents:
 * <ul>
 *  <li>Subalbums
 *  <li>Name
 *  <li>Description
 *  <li>Modification date
 *  <li>Author
 *  <li>Representative image
 * </ul>
 */
//=====================================

class Album
{
//------------------------------------------------------
public:

  ///Sets default information
  Album();

  ///Frees Subalbums
  ~Album();
 
  ///Sets the album name
  void setName(QString val);
  
  ///Gets the album name
  QString getName();

  ///Sets the album description
  void setDescription(QString val);
 
  ///Gets the album description
  QString getDescription();

  ///Sets the album author
  void setAuthor(QString val);

  ///Gets the album author
  QString getAuthor();  

  ///Sets the representative image
  void setRepresentativeImages(QImage* val);

  ///Returns the representative image
  QPixmap* getRepresentativeImage(int size);

  ///Returns a pointer to the first Subalbum
  Subalbum* getFirstSubalbum();

  ///Returns a pointer to the last Subalbum
  Subalbum* getLastSubalbum();

  ///Appends subalbum to end of linked list
  void appendSubalbum(Subalbum* val);
  
  ///Removes a subalbum
  void removeSubalbum(Subalbum* val);
  
  ///Returns the last modified year
  int getModificationYear();

  ///Returns the last modified month
  int getModificationMonth();

  ///Returns the last modified day
  int getModificationDay();

  ///Updates the modification date to today's date
  void updateModificationDate();

  ///Imports album from XML format
  void importFromDisk(LoadDialog* dialog, QString fileName);
  
  ///Exports album in XML and HTML format, along with resized images
  void exportToDisk(SaveDialog* dialog, QString dirName);
  
  ///Exports album in XML and HTML format, along with resized images,
  ///saves all files to the last saved directory, if none set
  ///returns
  void exportToDisk(SaveDialog* dialog, bool forceSave = false);
  
  ///Returns true if album previously saved to disk
  bool prevSave();

  ///Syncs subalbum ordering with front end gui ordering
  void syncSubalbumList(SubalbumPreviewWidget* item);
  
  ///Returns the current save location of all images
  QString getSaveLocation();
  
  ///Returns number of subalbums
  int getNumSubalbums();

//------------------------------------------------------
private:
  ///Exports album to XML
  void exportToXML(SaveDialog* dialog);

  ///Exports album to HTML
  void exportToHTML(SaveDialog* dialog);
  
  ///Exports subalbums to HTML
  void exportSublabumsToHTML(SaveDialog* dialog);
  
  ///Exports top level images
  void exportTopLevelImages();
  
  ///Exports subalbum images
  void exportSubalbumImages(SaveDialog* dialog, bool forceSave);

  ///Checks if images need to be moved and does so if necessary  
  void reorderSubalbumImages(SaveDialog* dialog);

  ///Removes old stagnant images caused when photos are removed from album or moved from one subalbum to another.  
  void removeStagnantImages(SaveDialog* dialog);
  
  ///Short name for album
  QString name;

  ///Longer description of album
  QString description;

  ///Album Creator
  QString author;

  ///Representative images
  QPixmap* smallRepresentativeImage;
  QPixmap* largeRepresentativeImage;

  ///Pointer to first Subalbum
  Subalbum* firstSubalbum;

  ///Pointer to last Subalbum
  Subalbum* lastSubalbum;

  ///Last modification year
  int modificationYear;

  ///Last modification month
  int modificationMonth;

  ///Last modification day
  int modificationDay;
  
  ///Number of subalbums
  int numSubalbums;
  
  ///Number of loaded subalbums
  int numLoadedSubalbums;
  
  ///Set if album was loaded/has been saved to disk
  bool savedToDisk;
  
  ///Directory album saved to
  QString saveLocation;
//------------------------------------------------------
};

#endif //BACKEND_ALBUM_H
