//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

//Systemwide includes
#include <iostream.h>
#include <fstream.h>
#include <stdio.h>
#include <qstring.h>
#include <qimage.h>

//Projectwide includes
#include "imageTools.h"
#include "../config.h"

//==============================================
///Returns new image dimensions keeping size ratio
void resizeImage(int originalWidth,
                 int originalHeight,
                 int maxWidth,
                 int maxHeight,
                 int& newWidth,
                 int& newHeight)
{
  //if original dimensions are within max new size then use
  //original dimensions
  if(originalWidth <= maxWidth &&
     originalHeight <= maxHeight)
  {
    newWidth = originalWidth;
    newHeight = originalHeight;
    return;
  }
  
  //else find dimension which is way over bounds
  float ratWidth = ((float)maxWidth) / ((float)originalWidth);
  float ratHeight = ((float)maxHeight) / ((float)originalHeight);
  
  if(ratWidth < ratHeight)
  {
    newWidth = maxWidth;
    newHeight = (int)((((float)maxWidth) / ((float)originalWidth)) * ((float)originalHeight));  
  }
  else
  {
    newHeight = maxHeight;
    newWidth = (int)((((float)maxHeight) / ((float)originalHeight)) * ((float)originalWidth));   
  }  
}
//==============================================
void copyFile(QString oldFile,
                    QString newFile)
{
  ifstream inputstream(oldFile.ascii(), ios::binary|ios::in);
  ofstream outputstream(newFile.ascii(), ios::binary|ios::out);

  char buffer[500];
  while(inputstream.is_open() && inputstream)
  {
    inputstream.read(buffer, 500);
    outputstream.write(buffer, 500);
  }

  inputstream.close();
  outputstream.close();
}
//==============================================
void createImages(QImage* fullImage,
                          QImage** slideshowImage,
                          QImage** thumbnailImage,
                          QImage** paddedThumbnailImage,
                          int &slideshowWidth,
                          int &slideshowHeight)
{
  //---------------------------------------------------------    
  if((*paddedThumbnailImage) != (*thumbnailImage))
    delete (*paddedThumbnailImage);
  delete (*thumbnailImage);
  delete (*slideshowImage);
  //---------------------------------------------------------    
  int thumbnailW = 0;
  int thumbnailH = 0;
  //---------------------------------------------------------    
  resizeImage( fullImage->width(), fullImage->height(),
               THUMBNAIL_WIDTH, THUMBNAIL_HEIGHT,
               thumbnailW, thumbnailH);
  resizeImage( fullImage->width(), fullImage->height(),
               SLIDESHOW_WIDTH, SLIDESHOW_HEIGHT,
               slideshowWidth, slideshowHeight);
  //---------------------------------------------------------    
  //scale slide show image
  QImage temp = fullImage->smoothScale( slideshowWidth, slideshowHeight );
  temp.setAlphaBuffer(true);
  //create full size slide show image
  (*slideshowImage) = new QImage(SLIDESHOW_WIDTH, SLIDESHOW_HEIGHT, fullImage->depth());
  (*slideshowImage)->setAlphaBuffer(true);
  //copy scaled image into centered portion of real slideshow image
  int xDiff = SLIDESHOW_WIDTH - slideshowWidth;
  int yDiff = SLIDESHOW_HEIGHT - slideshowHeight;

  //set all pixels to white
  int x,y;
  for(x=0; x< SLIDESHOW_WIDTH; x++)
  {
    for(y=0; y<SLIDESHOW_HEIGHT; y++)
    {
      (*slideshowImage)->setPixel(x, y, QColor(255, 255, 255).rgb()); 
    }
  }
  
  int x2 = 0;
  int y2;
  for(x = xDiff/2; x< (xDiff/2) + slideshowWidth; x++)
  {
    y2 = 0;
    for(y = yDiff/2; y < (yDiff/2) + slideshowHeight; y++)
    {
       (*slideshowImage)->setPixel(x, y, temp.pixel(x2, y2));
       y2++;
    }
    x2++;  
  }
  //---------------------------------------------------------    
  //scale down thumbnail image
  (*thumbnailImage) = new QImage(fullImage->smoothScale( thumbnailW, thumbnailH ));
  (*thumbnailImage)->setAlphaBuffer(true); 
  //---------------------------------------------------------    
  //if scaled thumbnail image is same size as padded thumbnail should be reuse object
  if(thumbnailW == THUMBNAIL_WIDTH &&
     thumbnailH == THUMBNAIL_HEIGHT)
  {
     (*paddedThumbnailImage) = (*thumbnailImage);
  }
  //else pad thumbnail
  else
  {
    //created padded thumbnail image
    (*paddedThumbnailImage) = new QImage(THUMBNAIL_WIDTH, THUMBNAIL_HEIGHT, fullImage->depth());
    (*paddedThumbnailImage)->setAlphaBuffer(true);
  
    //copy scaled image into centered portion of padded image
    xDiff = THUMBNAIL_WIDTH - thumbnailW;
    yDiff = THUMBNAIL_HEIGHT - thumbnailH;

    //set all pixels to white
    for(x=0; x< THUMBNAIL_WIDTH; x++)
    {
      for(y=0; y<THUMBNAIL_HEIGHT; y++)
      {
        (*paddedThumbnailImage)->setPixel(x, y, QColor(255, 255, 255).rgb()); 
      }
    }
  
    x2 = 0;
    for(x = xDiff/2; x< (xDiff/2) + thumbnailW; x++)
    {
      y2 = 0;
      for(y = yDiff/2; y < (yDiff/2) + thumbnailH; y++)
      {
        (*paddedThumbnailImage)->setPixel(x, y, (*thumbnailImage)->pixel(x2, y2));
        y2++;
      }
      x2++;  
    }
  }  
  //---------------------------------------------------------    
}
//==============================================

