//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

#ifndef GUI_PHOTOEDITWIDGET_H
#define GUI_PHOTOEDITWIDGET_H

//--------------------
//forward declarations
class QGridLayout;
class QLabel;
class QLineEdit;
class QPixmap;
class QImage;
class QPushButton;
class QFrame;
class LayoutWidget;
class PhotoViewWidget;
class Photo;
//--------------------

#include <qwidget.h>

//=====================================
/*! \brief Interface for editor photos. Operations may include redeye reduction, cropping, exposure adjustment, etc.
 */
//=====================================
class PhotoEditWidget : public QWidget
{
Q_OBJECT

public:
  ///Creates layout
  PhotoEditWidget(QWidget *parent=0, 
                          const char* name=0);
                 
  ///Deletes objects
  ~PhotoEditWidget();
  
  ///Sets the photo pointer
  void setPhoto(Photo* photo);
//----------------------
private slots:
  ///Updates photo description
  void updateDescription( const QString& val );
  
  ///Adjusts Exposure of entire image
  void adjustExposure();
  
  ///Cropped image to selected region
  void cropToRegion();

  ///Inverts image
  void invertSelection();
    
  ///Applies redeye reduction to selected region
  void reduceRedeye();
    
  ///Resets photo to state before editing took place  
  void resetImageAction();
  
  ///Returns to organizing mode
  void returnFromEdit();
  //----------------------  
private:
  ///Grid widgets are placed in
  QGridLayout* grid;

  ///Grid lower buttons are placed in
  QFrame* buttons;
  
  ///Grid for lower buttons
  QGridLayout* grid2;
  
  ///Label "Photo Description:"
  QLabel* photoDescription;

  ///Actual photo description
  QLineEdit* photoDescriptionVal;
  
  ///Pointer to backend photo
  Photo* photo;
  
  ///Backup of image before any manipulations were preformed, allows
  ///user to reset image
  QImage* originalImage;
  
  ///Photo view, provides interface to see image and select regions of it
  PhotoViewWidget* photoView;
  
  ///"Adj. Exposure" image
  QPixmap* adjExposureImage;
  
  ///"Adj. Exposure" button
  QPushButton* adjExposureButton;
  
  ///"Crop" image
  QPixmap* cropImage;
  
  ///"Crop" button
  QPushButton* cropButton;
  
  ///"Invert" image
  QPixmap* invertImage;
  
  ///"Invert" button
  QPushButton* invertButton;
  
  ///"Red Eye" image
  QPixmap* redEyeImage;
  
  ///"Red Eye" button
  QPushButton* redEyeButton;
  
  ///"Reset" image
  QPixmap* resetImage;
  
  ///"Reset" button
  QPushButton* resetButton;

  ///"Return" image
  QPixmap* returnImage;
  
  ///"Return" button
  QPushButton* returnButton;
  
  ///Pointer to the parent layout widget
  LayoutWidget* layout;
//----------------------
};
//======================

#endif //GUI_PHOTOEDITWIDGET_H
