//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

#ifndef GUI_PHOTOVIEWWIDGET_H
#define GUI_PHOTOVIEWWIDGET_H

//--------------------
//forward declarations
class QPixmap;
class QPoint;
class Photo;
//--------------------

#include <qwidget.h>

//=====================================
/*! \brief Display widget for photos. Used by the PhotoEditWidget.
 */
//=====================================
class PhotoViewWidget : public QWidget
{
Q_OBJECT

public:
  ///Creates layout
  PhotoViewWidget(QWidget *parent=0, 
                            const char* name=0);
                 
  ///Deletes objects
  ~PhotoViewWidget();
  
  ///Updates displayed photo
  void setPhoto(Photo* photo);
  
  ///Returns the current selected coordinates (actual slideshow image 
  ///space, aka not including buffered whitespace or widget offsets)
  void getSelection(QPoint &topLeft, QPoint &bottomRight);
  //----------------------
protected:
  void paintEvent( QPaintEvent *e);
  void mousePressEvent( QMouseEvent *e);
  void mouseReleaseEvent( QMouseEvent *);
  void mouseMoveEvent( QMouseEvent *e);
  void keyReleaseEvent( QKeyEvent *e);
  //----------------------
private slots:
 void selectAll();
  //----------------------
private:
  ///crops a selected point to within the photo
  QPoint cropSelectedPoint(QPoint p);
  
  ///Photo pixmap
  QPixmap* photo;
  
  ///Photo object handle
  Photo* photoObject;

  ///first corner of selection, where mouse first clicked
  QPoint* corner1;
  
  ///second corner of selection, where mouse moved to
  QPoint* corner2;
  
  ///currently dragging out selection, handle mouse move events
  bool currentlyDragging;  
//----------------------
};
//======================

#endif //GUI_PHOTOVIEWWIDGET_H
