//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

//Systemwide includes
#include <qpixmap.h>
#include <qstring.h>
#include <qpainter.h>

//Projectwide includes
#include "photoWidget.h"
#include "photosIconView.h"
#include "../backend/photo.h"

#include <iostream.h>

//==============================================
PhotoWidget::PhotoWidget( PhotosIconView *parent, 
                          Photo* phto ) : QIconViewItem( parent,
                                                         phto->getDescription(),
                                                         *phto->getImage(PADDED_THUMBNAIL) )
{
  this->parent = parent;
  this->phto = phto;
}
//==============================================
Photo* PhotoWidget::getPhoto()
{
  return phto;
}
//==============================================
void PhotoWidget::sync()
{
  phto->setDescription(text());  
}
//==============================================
void PhotoWidget::updateImage()
{
  this->setPixmap(*(phto->getImage(PADDED_THUMBNAIL)));
}
//==============================================
void PhotoWidget::updateDescription()
{
  this->setText( phto->getDescription() );
}
//==============================================
void PhotoWidget::paintItem( QPainter* p, 
                             const QColorGroup& cg)                          
{
  if(isSelected())
  {
    //draw red border around item
    int align = AlignHCenter;
    align |= WordBreak | BreakAnywhere;
    
    //create buffer to draw in
    QRect rct = rect();
    rct.moveBy(-x(), -y());
    QPixmap buffer( size() );
    //create a painter pointing to the buffer
    QPainter bp( &buffer );
    //paint to buffer
    bp.setBrushOrigin( p->brushOrigin() );
    bp.fillRect( rct, white );
    QRect pr = pixmapRect(false);
    pr.moveBy(-x(), -y());
    bp.drawPixmap(pr, *pixmap());
    QRect tr = textRect(false);
    tr.moveBy(-x(), -y());
    bp.drawText(tr,align, text());
    bp.setPen( red );    
    bp.drawRect(rct); 
    bp.end();
    //paint buffer to widget
    p->drawPixmap( x(), y(), buffer );
  }
  else
  {
    QIconViewItem::paintItem ( p, cg);
  }
}
//==============================================
void PhotoWidget::setText ( const QString & text )
{
  sync();
  QIconViewItem::setText(text);
}
//==============================================
void PhotoWidget::dropped( QDropEvent *e, const QValueList<QIconDragItem> & ) 
{
  if(e->source()->parentWidget() == parent)
  {
    if(e->pos().x() < (x() + (width()/2)))
    {
      parent->currentItem()->move(x() - 1, y());
    }
    else
    {
      parent->currentItem()->move(x() + (width()/2) + 1, y());
    }
  }
}
//==============================================
bool PhotoWidget::acceptDrop( const QMimeSource *) const
{
  return true;
}
//==============================================
int PhotoWidget::compare ( QIconViewItem * i ) const
{
  if( pos().y() > (i->pos().y() + height()) ||
      (
        pos().y() >= i->pos().y() &&
        pos().x() >= i->pos().x()
      ))
  { return 1; }
  else
  { return -1; }
}
//==============================================
