//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

//Systemwide includes
#include <qdialog.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qtextedit.h>
#include <qfont.h>
#include <qpushbutton.h>
#include <qpixmap.h>

//Projectwide includes
#include "questionDialog.h"
#include "../config.h"

//==============================================
QuestionDialog::QuestionDialog( QString question,
                                QString message,
                                QString questionIconName,
                                QWidget* parent,
                                const char* name ) : 
                                QDialog(parent, name, true )
{
  //-------------------------------
  //create widgets   
  windowIcon = new QPixmap(QString(IMAGE_PATH)+"albumShaperIcon.png");
  
  topFrame = new QFrame( this );  
  
  questionText = new QLabel( topFrame );
  questionText->setText( question );
  questionText->setFont( QFont( "Times", 12, QFont::Bold ) );

  questionIcon = new QPixmap(QString(IMAGE_PATH)+questionIconName);
  questionIconLabel = new QLabel( topFrame );
  questionIconLabel->setPixmap( *questionIcon );
    
  messageText = new QTextEdit( this );
  messageText->setReadOnly(true);  
  messageText->setText( message );
  messageText->setFont( QFont( "Times", 12, QFont::Normal ) );  

  bottomFrame = new QFrame( this );
  okButton = new QPushButton( QPixmap(QString(IMAGE_PATH)+"button_ok.png"), 
                              "Ok", 
                              bottomFrame );
  okButton->setSizePolicy( QSizePolicy::Maximum, QSizePolicy::Maximum );
  connect( okButton, SIGNAL(clicked()), SLOT(accept()) );

  cancelButton = new QPushButton( QPixmap(QString(IMAGE_PATH)+"button_cancel.png"), 
                                  "Cancel", 
                                  bottomFrame );
  cancelButton->setSizePolicy( QSizePolicy::Maximum, QSizePolicy::Maximum );
  connect( cancelButton, SIGNAL(clicked()), SLOT(reject()) );
  //-------------------------------
  //create grid and place widgets
  gridTop     = new QGridLayout( topFrame, 1, 2, 0);
  gridTop->addWidget( questionText, 0, 0 );
  gridTop->addWidget( questionIconLabel, 0, 1, Qt::AlignRight );
  
  gridBottom  = new QGridLayout( bottomFrame, 1, 2, 0);
  gridBottom->addWidget( okButton, 0, 0 );
  gridBottom->addWidget( cancelButton, 0, 1);
  
  gridFull    = new QGridLayout( this, 3, 1, 0);
  gridFull->addWidget( topFrame, 0, 0);
  gridFull->addWidget( messageText, 1, 0);
  gridFull->addWidget( bottomFrame, 2, 0);
  
  gridFull->setRowStretch( 1, 1 );     
  gridFull->setResizeMode( QLayout::FreeResize );
  
  setMinimumWidth(300);
  setMaximumWidth(300);
  //-------------------------------
  //set the background of the widget to be white
  setPaletteBackgroundColor( QColor(255, 255, 255) );
  //-------------------------------
  //setup window title bar
  setIcon( *windowIcon );
  setCaption( question );
  //-------------------------------
}
//==============================================
QuestionDialog::~QuestionDialog()
{
  delete windowIcon;
  delete questionIcon;
}
//==============================================
