//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

#ifndef GUI_SUBALBUMWIDGET_H
#define GUI_SUBALBUMWIDGET_H

//--------------------
//forward declarations
class QGridLayout;
class QLabel;
class QLineEdit;
class QPixmap;
class QIconView;
class PhotosIconView;
class QPushButton;
class QFrame;
class Subalbum;
class LayoutWidget;
class Photo;

class QIconViewItem;
//--------------------

#include <qwidget.h>

//=====================================
/*! \brief Displays subalbum layout, name and description.
 */
//=====================================
class SubalbumWidget : public QWidget
{
Q_OBJECT

public:
  ///Creates layout based on backend object
  SubalbumWidget(Subalbum* salbum,
                 QWidget *parent=0, 
                 const char* name=0);
                 
  ///Deletes objects
  ~SubalbumWidget();

  ///Resets the subalbum this subalbum widget is displaying
  void setSubalbum(Subalbum* salbum);
  
  ///refreshes all photos
  void refreshPhotos();

  ///refreshes selected photos
  void refreshSelectedPhotos();
  
  ///Syncs all photo data to backend objects
  void syncPhotos();
  
  ///returns a pointer to the backend subalbum
  Subalbum* getSubalbum();

  ///Returns currently selected photo. If no or multiple photos selected returns NULL
  Photo* getSelectedPhoto();

  ///Returns pointer to icon view
  QIconView* getPhotos();

  ///Activates/Deactives remove/rotate/flip buttons
  void updateButtons(bool enable);
//----------------------
private slots:
  ///Updates subalbum name
  void updateName( const QString& val );

  ///Updates subalbum description
  void updateDescription( const QString& val );

  ///Sets currently selected photo as the representative image for the subalbum
  void setImageAction();

  ///Activates/Deactives remove/rotate/flip buttons depending on if an image is selected
  void updateButtons();
  
  ///Adds an image to the subalbum
  void addImageAction();

  ///Remove an image from the subalbum
  void removeImageAction();

  ///Rotate clockwise selected images
  void rotate90ImageAction();
    
  ///Rotate counter-clockwise selected images
  void rotate270ImageAction();

  ///Flip about horizontal axis selected images
  void flipHorizontallyImageAction();
  
  ///Flip about vertical axis selected images
  void flipVerticallyImageAction();    
    
  ///Brings up the edit dialog for the currently selected photo
  void editAction();    
  
  ///Rearranges photos and saves their text
  void rearrangeAndSaveCurrent( QIconViewItem* item);
  
  //Rearranges subalbums in grid
  void reorder();
  //----------------------
protected:
    void resizeEvent( QResizeEvent * );
  //----------------------
private:
  ///Grid widgets are placed in
  QGridLayout* grid;

  ///Grid lower buttons are placed in
  QFrame* buttons;
  
  QGridLayout* grid2;
  
  ///Label "Subalbum Name:"
  QLabel* subalbumName;

  ///Actual subalbum name
  QLineEdit* subalbumNameVal;

  ///Label "Description:"
  QLabel* subalbumDescription;

  ///Actual subalbum description
  QLineEdit* subalbumDescriptionVal;

  ///Label which shows "set" image
  QLabel* representativeImageText;

  ///"Set" image
  QPixmap* setImageImage;

  ///Button allowing user to set the representative image for the subalbum
  QPushButton* setImage;

  ///Label which shows the representative image
  QLabel* representativeLogo;

  ///Representative image
  QPixmap* representativeImage;

  ///Photos layout
  PhotosIconView* photos;

  ///Pointer to backend subalbum
  Subalbum* subalbum;
  
  ///"Add" image
  QPixmap* addImageImage;
  
  ///"Add" button
  QPushButton* addImage;
  
  ///"Remove" image
  QPixmap* removeImageImage;
  
  ///"Remove" button
  QPushButton* removeImage;
  
  ///"Rotate 90" image
  QPixmap* rotate90ImageImage;
  
  ///"Rotate 90" button
  QPushButton* rotate90Image;

  ///"Rotate 270" image
  QPixmap* rotate270ImageImage;
  
  ///"Rotate 270" button
  QPushButton* rotate270Image;
  
  ///"Flip Horizontally" image
  QPixmap* flipHorizontallyImageImage;
  
  ///"Flip Horizontally" button
  QPushButton* flipHorizontallyImage;

  ///"Flip Vertically" image
  QPixmap* flipVerticallyImageImage;
  
  ///"Flip Vertically" button
  QPushButton* flipVerticallyImage;
    
  ///"Edit"" image
  QPixmap* editImage;
  
  ///"Edit" button
  QPushButton* editButton;
  
  ///Pointer to the parent layout widget
  LayoutWidget* layout;
  
  ///cached enabled/disabled state of buttons
  bool buttonsState;
//----------------------
};
//======================

#endif //GUI_SUBALBUMWIDGET_H
