//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

#ifndef GUI_TITLEWIDGET_H
#define GUI_TITLEWIDGET_H

//--------------------
//forward declarations
class QMenuBar;
class QPopupMenu;
class QGridLayout;
class QLabel;
class QLineEdit;
class QPixmap;
class QPushButton;
class Album;
class Window;
class About;
//--------------------

#include <qframe.h>

//=====================================
/*! \brief Widget which displays album name, description, representative 
   image, and album shaper logo.
 */
//=====================================
class TitleWidget : public QFrame
{
Q_OBJECT

public:
  ///Creates layout
  TitleWidget(QWidget *parent=0, const char* name=0);
  
  ///Deletes all objects
  ~TitleWidget();
  
  ///Sets new pointer to the album object
  void setAlbum( Album* val);
  
  ///Returns a pointer to the album object
  Album* getAlbum();
  
  ///Refreshs data from backend objects
  void refresh();
  
  ///Set active state of set button
  void setSetButtonState(bool state);
  
  ///is program busy?
  bool getBusy();
  
  ///set program busy state
  void setBusy(bool val);
//----------------------
public slots:
  ///Frees about box once closed
  void aboutClosed();
//----------------------
private slots:
  ///Updates album name
  void updateName( const QString& val );
  
  ///Updates album description
  void updateDescription( const QString& val );

  ///Updates album author
  void updateAuthor( const QString& val );

  ///Sets currently selected photo as the representative image for the subalbum
  void setImageAction();
  
  ///Resets to empty album
  void newAlbum();
  
  ///Loads a new album
  void loadAlbum();
  
  ///Saves album
  void saveAlbum();
  
  ///Saves album as
  void saveAsAlbum();
  
  ///Pops up about window
  void aboutProgram();
//----------------------
private:
  ///Menubar file menu and help menu inserted in
  QMenuBar* menu;
  
  ///File menu
  QPopupMenu* file;
  
  ///Help menu
  QPopupMenu* help;

  ///Layout widgets placed in
  QGridLayout* grid;

  ///"Album Name:" label
  QLabel* albumName;

  ///Actual album name
  QLineEdit* albumNameVal;

  ///"Description:" label
  QLabel* albumDescription;

  ///Actual album description
  QLineEdit* albumDescriptionVal;

  ///"Author:" label
  QLabel* albumAuthor;

  ///Actual album author
  QLineEdit* albumAuthorVal;  
  
    ///Label which shows "set" image
  QLabel* representativeImageText;

  ///"Set" image
  QPixmap* setImageImage;

  ///Button allowing user to set the representative image for the subalbum
  QPushButton* setImage;

  ///Label which shows the representative image
  QLabel* representativeLogo;

  ///Representative image
  QPixmap* representativeImage;

  ///Album Shaper Logo
  QPixmap* albumShaperImage;

  ///Label which shows Album Shaper logo
  QLabel* albumShaperLogo;

  ///Horizontal line
  QFrame* line;
  
  ///Backend album object
  Album* albm;
  
  ///Window pointer
  Window* window;
  
  ///About box pointer
  About* about;
  
  ///Is the program currently busy? helps block other operations
  bool busy;
  
  //file menu item id's
  int NEW_ALBUM;
  int OPEN_ALBUM;
  int SAVE_ALBUM;
  int SAVEAS_ALBUM;

   //cached set button state
   bool cacheSetButtonState;
  
//----------------------
};
//======================

#endif //GUI_TITLEWIDGET_H
