//==============================================
//  copyright            : (C) 2003 by Will Stokes
//==============================================
//  This program is free software; you can redistribute it 
//  and/or modify it under the terms of the GNU General 
//  Public License as published by the Free Software 
//  Foundation; either version 2 of the License, or  
//  (at your option) any later version.         
//
//  As a special exception, Will Stokes gives permission to 
//  link this program with Qt non-commercial edition, and 
//  distribute the resulting executable, without including the 
//  source code for the Qt non-commercial edition in the 
//  source distribution. 
//==============================================

//Systemwide includes
#include <qapplication.h>
#include <qlayout.h>

//Projectwide includes
#include "gui/window.h"
#include "config.h"

#include <iostream.h>


/*! \mainpage 
 *  AlbumShaper is a Qt app which allows easy hierarchical 
 *  photo album creation and editing using a drag-n-drop interface.
 */

#define DEFAULT_WIDTH 875
#define DEFAULT_HEIGHT 620 

int main( int argc, char **argv)
{ 
  //set image path
  if(argc > 1)
    IMAGE_PATH = QString(argv[1]).replace("/usr/local/bin", "/usr/local/share/albumshaper") + "/images/";
  else
    IMAGE_PATH = "images/";
  
  QApplication a(argc, argv);

  Window window;
  a.setMainWidget( &window );
  window.show();

  //determine default window size
  
  //set defaults
  int width = DEFAULT_WIDTH;
  int height = DEFAULT_HEIGHT;
  
  //if window size greater than desktop available then decrease
  QDesktopWidget *desktop = QApplication::desktop();
  if(width > desktop->width())
  { width = desktop->width(); }
  if(height > desktop->height())
  { height = desktop->height(); }
  
  //if window already must be larger than defaults then enlarge
  if(width < window.geometry().width())
  { width = window.geometry().width(); }
  if(height < window.geometry().height())
  { height = window.geometry().height(); }
  
  //compute offsets such that window centered on screen
  int xOffset = (desktop->width() - width) / 2;
  int yOffset = (desktop->height() - height) / 2;
  
  //set size and offset and show window
  window.setGeometry(xOffset, yOffset, width, height);
  window.repaint();
  a.exec();
}
